@@ -5,8 +5,6 @@ Arrivals->Router->Job/Servicing.
 """
 #   TODO: Rewrite POI/EXP as implementations of the general functions Job/GeneralArrivals
 
-import random
-
 from simpy import Interrupt
 
 
@@ -61,85 +59,6 @@ def Job(doPrint, queuesOverTime, replicaDict, env, name, arrive, queues, choice,
                 Exception(f"Request error for {queues[choice].request()}")
 
 
-def ExpJob(doPrint, meanServer, queuesOverTime, replicaDict, env, name, arrive, queues, choice, **kwargs):
-    """For a redundancy model, this generator/process defines the behaviour of a job (replica or original) after routing.
-    This particular form assumes the service distribution to be exponential
-
-    :param doPrint: If true, each event will trigger a statement to be printed.
-    :param meanServer: Mean servicing time.
-    :param queuesOverTime: A set of queues passed by the simulation manager representing the time-evolution of the system.
-    :type queuesOverTime: List[simpy.Resource]
-    :param replicaDict: A set of a job and its replications, of which this generator itself is a member of.
-    :type replicaDict: {str: List[simpy.Process]}
-    :param env: Environment for the simulation
-    :type env: simpy.Environment
-    :param name: Identifier for the job.
-    :type name: str
-    :param queues: A list of queuesOverTime.
-    :type queues: List[simpy.Resource]
-    :param arrive: Time of job arrival (before replication).
-    :type arrive: float
-    :param choice: The queue which this replica is currently in
-    :type choice: int
-    """
-    if kwargs["Service"]:
-        print("WARNING: kwargs given are ignored in the current context!")
-    try:
-        with queues[choice].request() as request:
-            # Wait in queue
-            Rename = f"{name}@{choice}"
-            yield request
-            wait = env.now - arrive
-            # at server
-            if doPrint:
-                print(f'{env.now:7.4f} {Rename}: Waited {wait:6.3f}')
-            tib = random.expovariate(1.0 / meanServer)
-            yield env.timeout(tib)
-            queuesOverTime.append({i: len(queues[i].put_queue) for i in range(len(queues))})
-            if doPrint:
-                print(f'{env.now:7.4f} {Rename}: Finished')
-            if replicaDict:
-                for c in replicaDict[name]:
-                    try:
-                        c.interrupt()
-                    except:
-                        pass
-    except Interrupt:
-        if doPrint:
-            print(f"    ↳ {Rename} - interrupted")
-
-
-def PoissonArrivals(system, env, number, interval, queues, **kwargs):
-    """Poisson arrival process; interarrival times are generated by :math:`\\text{EXP}(\\frac{1}{\lambda})`
-
-    :param system: System providing environment.
-    :param env: Environment for the simulation
-    :type env: simpy.Environment
-    :param number: Max numberJobs of jobs if infiniteJobs is false.
-    :type number: int
-    :param interval: Poisson rate parameter :math:`\lambda`.
-    :type interval: float
-    :param queues: A list of all queues making up the parallel system.
-    :type queues: List[simpy.Resource]
-    """
-    if kwargs["Arrival"]:
-        print("WARNING: kwargs given are ignored in the current context!")
-    if not system.infiniteJobs:
-        for i in range(number):
-            c = JobRouter(system, env, 'Job%02d' % i, queues)
-            env.process(c)
-            t = random.expovariate(1.0 / interval)
-            yield env.timeout(t)
-    else:
-        while True:  # referring to until not being passed
-            i = number
-            number += 1
-            c = JobRouter(system, env, 'Job%02d' % i, queues)
-            env.process(c)
-            t = random.expovariate(1.0 / interval)
-            yield env.timeout(t)
-
-
 def JobRouter(system, env, name, queues, **kwargs):
     """Specifies the scheduling system used. If replication is enabled, this is the superclass for the set of each job and their replicas.
 
@@ -155,8 +74,8 @@ def JobRouter(system, env, name, queues, **kwargs):
     arrive = env.now
     Q_length = {i: system.NoInSystem(queues[i]) for i in system.QueueSelector(system.d, queues)}
     system.queuesOverTime.append({i: len(queues[i].put_queue) for i in range(len(queues))})
-    choices = []
     if system.ReplicaDict is not None:  # Replication chosen
+        choices = []
         if system.r:
             for i, value in Q_length.items():
                 if value <= system.r:
@@ -179,8 +98,7 @@ def JobRouter(system, env, name, queues, **kwargs):
     else:  # Shortest queue case
         if system.doPrint:
             print(f'{arrive:7.4f} {name}: Arrival')
-        for i in Q_length:
-            choices.append(i)
+        choices = [i for i in Q_length]
         choice = min(choices)
         c = Job(system.doPrint, system.queuesOverTime, None, env, name, arrive, queues, choice, **kwargs)
         env.process(c)
